/**************************************************************************************************
Revised:
Revision:

Copyright 2007 Texas Instruments Incorporated.  All rights reserved.

IMPORTANT: Your use of this Software is limited to those specific rights granted under
the terms of a software license agreement between the user who downloaded the software,
his/her employer (which must be your employer) and Texas Instruments Incorporated (the
"License"). You may not use this Software unless you agree to abide by the terms of the
License. The License limits your use, and you acknowledge, that the Software may not be
modified, copied or distributed unless embedded on a Texas Instruments microcontroller
or used solely and exclusively in conjunction with a Texas Instruments radio frequency
transceiver, which is integrated into your product. Other than for the foregoing purpose,
you may not use, reproduce, copy, prepare derivative works of, modify, distribute,
perform, display or sell this Software and/or its documentation for any purpose.

YOU FURTHER ACKNOWLEDGE AND AGREE THAT THE SOFTWARE AND DOCUMENTATION ARE PROVIDED AS IS
WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION, ANY
WARRANTY OF MERCHANTABILITY, TITLE, NON-INFRINGEMENT AND FITNESS FOR A PARTICULAR PURPOSE.
IN NO EVENT SHALL TEXAS INSTRUMENTS OR ITS LICENSORS BE LIABLE OR OBLIGATED UNDER CONTRACT,
NEGLIGENCE, STRICT LIABILITY, CONTRIBUTION, BREACH OF WARRANTY, OR OTHER LEGAL EQUITABLE
THEORY ANY DIRECT OR INDIRECT DAMAGES OR EXPENSES INCLUDING BUT NOT LIMITED TO ANY
INCIDENTAL, SPECIAL, INDIRECT, PUNITIVE OR CONSEQUENTIAL DAMAGES, LOST PROFITS OR LOST
DATA, COST OF PROCUREMENT OF SUBSTITUTE GOODS, TECHNOLOGY, SERVICES, OR ANY CLAIMS BY
THIRD PARTIES (INCLUDING BUT NOT LIMITED TO ANY DEFENSE THEREOF), OR OTHER SIMILAR COSTS.

Should you have any questions regarding your right to use this Software,
contact Texas Instruments Incorporated at www.TI.com.
**************************************************************************************************/

/* =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
*   BSP (Extended Board Support Package)
*
*   LED Lighting Control
*   
*   Two pins are used to control the LED lighting.
*   Port0_0: active low signal which controls the on/off and flashing
*   Port1_1: PWM signal provides the dimmer functions.
*
*   Dimmer function is implemented by using Timer 1 in PWM mode.
*   Flashing function is provided by using Timer 4.
*
* =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
*/


/* ------------------------------------------------------------------------------------------------
*                                            Includes
* ------------------------------------------------------------------------------------------------
*/
#include "bsp.h"
#include "mrfi.h"
#include "nwk_types.h"
#include "nwk_api.h"
#include "bsp_leds.h"
#include "bsp_buttons.h"
#include "bsp_extended.h"


/* ------------------------------------------------------------------------------------------------
 *                                          Macros
 * ------------------------------------------------------------------------------------------------
 */
 /* set 16-bits PWM width *//* start timer1*/
#define SET_TIMER1_PWM_WIDTH(x)       { T1CC1L = ((x)&0xff);      \
                                        T1CC1H = (((x)>>8)&0xff); \
                                        T1CTL |= 0x02; }          


/* ------------------------------------------------------------------------------------------------
 *                                           Defines
 * ------------------------------------------------------------------------------------------------
 */
/* sLEDstate, 
* bit 0-3 : LED dimmer level, bit 4-6 : LED flash mode, bit 7 : LED on/off
*/
#define LED_STATE_ON          0x80
#define LED_STATE_OFF         ~0x80

#define LED_STATE_PWM_STATE_MASK    0x0f
#define LED_STATE_PWM_STATE_0       0
#define LED_STATE_PWM_STATE_1       1
#define LED_STATE_PWM_STATE_2       2
#define LED_STATE_PWM_STATE_3       3
#define LED_STATE_PWM_STATE_4       4
#define LED_STATE_PWM_STATE_5       5
#define LED_STATE_PWM_STATE_6       6
#define LED_STATE_PWM_STATE_7       7
#define LED_STATE_PWM_STATE_8       8
#define LED_STATE_PWM_STATE_9       9
#define LED_STATE_PWM_STATE_10      10
#define LED_STATE_PWM_STATE_11      11
#define LED_STATE_PWM_STATE_12      12
#define LED_STATE_PWM_STATE_13      13
#define LED_STATE_PWM_STATE_14      14
#define LED_STATE_PWM_STATE_15      15

#define LED_STATE_FLASH_MODE_BIT_POSITION   4
#define LED_STATE_FLASH_MODE_MASK           0x70
#define LED_STATE_FLASH_MODE_0              0x00
#define LED_STATE_FLASH_MODE_1              0x10
#define LED_STATE_FLASH_MODE_2              0x20
#define LED_STATE_FLASH_MODE_3              0x30
#define LED_STATE_FLASH_MODE_4              0x40
#define LED_STATE_FLASH_MODE_5              0x50


/* PWM duty cycle defines */
#define PWM_15_16_DUTY        0x01e0
#define PWM_14_16_DUTY        0x01c0
#define PWM_13_16_DUTY        0x01a0
#define PWM_12_16_DUTY        0x0180
#define PWM_11_16_DUTY        0x0160
#define PWM_10_16_DUTY        0x0140
#define PWM_9_16_DUTY         0x0120
#define PWM_8_16_DUTY         0x0100
#define PWM_7_16_DUTY         0x00e0
#define PWM_6_16_DUTY         0x00c0
#define PWM_5_16_DUTY         0x00a0
#define PWM_4_16_DUTY         0x0080
#define PWM_3_16_DUTY         0x0060
#define PWM_2_16_DUTY         0x0040
#define PWM_1_16_DUTY         0x0020

/* PWM duty cycle defines */
#define PWM_8_10_DUTY        0x019a
#define PWM_6_10_DUTY        0x0134
#define PWM_4_10_DUTY        0x00ce
#define PWM_2_10_DUTY        0x0068
#define PWM_5_100_DUTY       0x001a


/* FlashCount defines */
/* 200 count ~= 2.5ms x 200 = 0.5s */

/* flashing mode 1: Slow flashing - 1.5 sec on and 1.5 sec off */
#define FLASHCOUNT_1P5_SEC    600
#define FLASHCOUNT_3_SEC      1200

/* flashing mode 2: Fast flashing - 0.5 sec on and 0.5 sec off */
#define FLASHCOUNT_0P5_SEC    200
#define FLASHCOUNT_1_SEC      400

/* flashing mode 3: Slow flashing for 6 sec then Fast flashing for 4 sec */
#define FLASHCOUNT_6_SEC      2400
#define FLASHCOUNT_10_SEC     4000

/* flashing mode 4: Fast flashing for 2 sec then pause for 2 sec */
#define FLASHCOUNT_2_SEC      800
#define FLASHCOUNT_4_SEC      1600

/* flashing mode 5: Fast flashing for 3 sec at 10/10 duty, 8/10 duty, 6/10 duty, 4/10 duty and 2/10 duty */
/*                  Flashing for total 15 sec                                                            */
#define FLASHCOUNT_5_SEC      2000
#define FLASHCOUNT_7_SEC      2800
#define FLASHCOUNT_8_SEC      3200
#define FLASHCOUNT_9_SEC      3600
#define FLASHCOUNT_11_SEC     4400
#define FLASHCOUNT_12_SEC     4800
#define FLASHCOUNT_13_SEC     5200
#define FLASHCOUNT_14_SEC     5600
#define FLASHCOUNT_15_SEC     6000


/* ------------------------------------------------------------------------------------------------
*                                            Local Variables
* ------------------------------------------------------------------------------------------------
*/
static uint8_t  sLEDstate;
static uint16_t sFlashCount, sFlashCount1, sFlashCount2;


/* ------------------------------------------------------------------------------------------------
*                                            Local Functions
* ------------------------------------------------------------------------------------------------
*/




/**************************************************************************************************
* @fn          BSP_initPWM
*
* @brief       initialization of Timer 1 in PWM mode
*              and Timer 4 for flashing function
*
* @param       None
* 
* @return      None
**************************************************************************************************
*/
void BSP_initPWM(void)
{
    /* reset sLEDstate which store the current state */
    sLEDstate=0;
    
    /* Timer 1 in Modulo Mode, Freq. set by T1 channel 0 */
    /* 13M / 511 / prescaler = 198.75Hz */
    T1CC0L = 0xff;
    T1CC0H = 0x01;
 
    /* init T1 channel 1 must smaller than channel 0 */
    T1CC1L = 0x10;
    T1CC1H = 0x00;

    /* T1 channel 1 set compare mode */
    T1CCTL1 |=  0x24;
    /* Prescaler set to Tick Freq / 128 */
    T1CTL |= 0x0c;

    /* Reset PWM output pin by triggering a zero count */
    /* start timer */
    T1CTL |= 0x02;      
    /* reset T1 counter */
    T1CNTL = 0x00;
    BSP_Delay(100);
    /* Stop timer */
    T1CTL &= ~0x03;      

    /* T1CFG set to Alt 2 location */
    PERCFG |= 0x40;
    /* P1_1 set peripheral func which associated with Timer 1 output */
    P1SEL |= 0x2;

    /* T4 Divider set free run, tick freq / 128 */
    /* freq = 13M/256/128 = 397Hz */
    T4CTL |= 0xe0;
}


/**************************************************************************************************
* @fn          toggleLED
*
* @brief       Control the LED lighting
*
* @param       message received
*              8 - toggle On/Off, 9 - switch to next dimmer level ,
*              10 - switch to next flashing mode
*
* @return      None
**************************************************************************************************
*/
void BSP_toggleLED(uint8_t message)
{
    uint8_t temp1;
  
    BSP_TOGGLE_LED1();

    /* command to Toggle On/ Off */
    /* ------------------------- */
    if (message == MESSAGE_TOGGLE_ON_OFF)
    {      
      /* if LED is ON, turn OFF LED */ 
      if (sLEDstate & LED_STATE_ON)
      {
      /* set P0_0 to high to turn off LED */
      BSP_TURN_OFF_LED2();
      /* reset all state */
      sLEDstate = 0;

      /* Reset PWM output pin by triggering a zero count */
      /* reset T1 counter */
      T1CNTL = 0x00;
      BSP_Delay(100);
      /* Stop timer */
      T1CTL &= ~0x03;      

      /* reset T4 counter */
      T4CTL |= 0x04;
      /* Stop Timer */
      T4CTL &= ~0x10;

      /* disable T4 int */
      IEN1 &= ~0x10;
      /* clear T4 int flag */
      IRCON &= ~0x10;      
      }
      /* if LED is OFF, turn ON LED */
      else
      {
        /* if dimmer contorl, turn on PWM */
        if (sLEDstate & LED_STATE_PWM_STATE_MASK)
          T1CTL |= 0x02;          

        /* set P0_0 to low to turn on LED */
        BSP_TURN_ON_LED2();
        sLEDstate |= LED_STATE_ON;
        
        /* if flashing, turn on T4 */
        if (sLEDstate & LED_STATE_FLASH_MODE_MASK)
        {
          sFlashCount1 = 0;
          sFlashCount2 = 0;

          /* start T4 */
          T4CTL |= 0x10;
          /* clear T4 int flag */  
          IRCON &= ~0x10;
          /* enable T4 int */
          IEN1 |= 0x10;
        }
      }     
    }
  
    /* command to switch to next dimmer level*/
    /* ------------------------------------- */
    else if ( (message == MESSAGE_DIMMER_UP) || (message == MESSAGE_DIMMER_DOWN) )
    {
      /* turn on LED */
      BSP_TURN_ON_LED2();
      sLEDstate |= LED_STATE_ON;
  
      temp1 = sLEDstate & LED_STATE_PWM_STATE_MASK;
      /* decrease brightness until min */
      if ( (message == MESSAGE_DIMMER_DOWN) && (temp1 < LED_STATE_PWM_STATE_15) )
        temp1++;
      /* increase brightness until max */
      if ( (message == MESSAGE_DIMMER_UP) && (temp1 > LED_STATE_PWM_STATE_0) )
        temp1--;
      
      /* 15/16 duty */
      if (temp1 == LED_STATE_PWM_STATE_1)
        SET_TIMER1_PWM_WIDTH(PWM_15_16_DUTY)
      /* 14/16 duty */
      else if (temp1 == LED_STATE_PWM_STATE_2)
        SET_TIMER1_PWM_WIDTH(PWM_14_16_DUTY)
      /* 13/16 duty */
      else if (temp1 == LED_STATE_PWM_STATE_3)
        SET_TIMER1_PWM_WIDTH(PWM_13_16_DUTY)
      /* 12/16 duty */
      else if (temp1 == LED_STATE_PWM_STATE_4)
        SET_TIMER1_PWM_WIDTH(PWM_12_16_DUTY)
      /* 11/16 duty */
      else if (temp1 == LED_STATE_PWM_STATE_5)
        SET_TIMER1_PWM_WIDTH(PWM_11_16_DUTY)
      /* 10/16 duty */
      else if (temp1 == LED_STATE_PWM_STATE_6)
        SET_TIMER1_PWM_WIDTH(PWM_10_16_DUTY)
      /* 9/16 duty */
      else if (temp1 == LED_STATE_PWM_STATE_7)
        SET_TIMER1_PWM_WIDTH(PWM_9_16_DUTY)
      /* 8/16 duty */
      else if (temp1 == LED_STATE_PWM_STATE_8)
        SET_TIMER1_PWM_WIDTH(PWM_8_16_DUTY)
      /* 7/16 duty */
      else if (temp1 == LED_STATE_PWM_STATE_9)
        SET_TIMER1_PWM_WIDTH(PWM_7_16_DUTY)
      /* 6/16 duty */
      else if (temp1 == LED_STATE_PWM_STATE_10)
        SET_TIMER1_PWM_WIDTH(PWM_6_16_DUTY)
      /* 5/16 duty */
      else if (temp1 == LED_STATE_PWM_STATE_11)
        SET_TIMER1_PWM_WIDTH(PWM_5_16_DUTY)
      /* 4/16 duty */
      else if (temp1 == LED_STATE_PWM_STATE_12)
        SET_TIMER1_PWM_WIDTH(PWM_4_16_DUTY)
      /* 3/16 duty */
      else if (temp1 == LED_STATE_PWM_STATE_13)
        SET_TIMER1_PWM_WIDTH(PWM_3_16_DUTY)
      /* 2/16 duty */
      else if (temp1 == LED_STATE_PWM_STATE_14)
        SET_TIMER1_PWM_WIDTH(PWM_2_16_DUTY)
      /* 1/16 duty */
      else if (temp1 == LED_STATE_PWM_STATE_15)
        SET_TIMER1_PWM_WIDTH(PWM_1_16_DUTY)
      /* 16/16 duty */
      else if (temp1 == LED_STATE_PWM_STATE_0)
      {
        /* reset T1 counter */
        T1CNTL = 0x00;
        BSP_Delay(100);
        /* Stop timer */
        T1CTL &= ~0x03;
      }
  
      sLEDstate &= ~LED_STATE_PWM_STATE_MASK;
      sLEDstate |= temp1;
    }

    /* command to switch to next Flashing mode */
    /* --------------------------------------- */
    else if ( (message == MESSAGE_FLASH_MODE_UP) || (message == MESSAGE_FLASH_MODE_DOWN) )
    {
      /* turn on LED */
      BSP_TURN_ON_LED2();
      sLEDstate |= LED_STATE_ON;
  
      /* switch to next mode */
      temp1 = sLEDstate & LED_STATE_FLASH_MODE_MASK;
      temp1 >>= LED_STATE_FLASH_MODE_BIT_POSITION;
  
      /* decrease flash mode and cycle if min  */
      if ( (message == MESSAGE_FLASH_MODE_UP) )
      {
        if (temp1 == (LED_STATE_FLASH_MODE_0>>LED_STATE_FLASH_MODE_BIT_POSITION) )
          temp1 = (LED_STATE_FLASH_MODE_5>>LED_STATE_FLASH_MODE_BIT_POSITION);
        else
          temp1--;
      }
      
      /* increase flash mode and cycle if max */
      if ( (message == MESSAGE_FLASH_MODE_DOWN) )
      temp1++;
      if (temp1 > (LED_STATE_FLASH_MODE_5>>LED_STATE_FLASH_MODE_BIT_POSITION))
         temp1 = (LED_STATE_FLASH_MODE_0>>LED_STATE_FLASH_MODE_BIT_POSITION);
      
      /* reset counters */
      sFlashCount1 = 0;
      sFlashCount2 = 0;
  
      /* Reset state and turn on LED */    
      if (temp1==(LED_STATE_FLASH_MODE_0>>LED_STATE_FLASH_MODE_BIT_POSITION))
      {
         /* reset PWM output */
         T1CNTL = 0x00;
         BSP_Delay(100);
         T1CTL &= ~0x03;      
        
        /* rest T4 cnt */
         T4CTL |= 0x04;
        /* stop T4 */
        T4CTL &= ~0x10;
        /* disable T4 int */
        IEN1 &= ~0x10;
        /* clear T4 int flag */
        IRCON &= ~0x10;     
        
        /* turn on LED */
        BSP_TURN_ON_LED2();
      }
      /* Flashing mode, turn on T4 */
      /* Flashing control will be done in T4 interrupt routine */
      else
      {
         /* reset PWM output */
         T1CNTL = 0x00;
         BSP_Delay(100);
         T1CTL &= ~0x03;      
  
        /* rest T4 cnt */
        T4CTL |= 0x04;
        /* start T4 */
        T4CTL |= 0x10;
        /* clear T4 int flag */  
        IRCON &= ~0x10;
        /* enable T4 int */
        IEN1 |= 0x10;
        
        /* turn on LED */
        BSP_TURN_ON_LED2();
      }
  
      sLEDstate &= ~LED_STATE_FLASH_MODE_MASK;
      temp1 <<= LED_STATE_FLASH_MODE_BIT_POSITION;
      temp1 &= LED_STATE_FLASH_MODE_MASK;
      sLEDstate |= temp1;     
    }
      
  return;
}



/**************************************************************************************************
* @fn          bsp_Timer4ISR
*
* @brief       Timer 4 interrupt routine, control LED Flashing
*              freq = 13M / 256 / prescaler
*                   = 13M / 256 / 128
*                   = 397 Hz ~= 2.5ms
* @param       None
*
* @return      None
**************************************************************************************************
*/
BSP_ISR_FUNCTION(bsp_Timer4ISR, T4_VECTOR)
{
    /* if Timer 4 interrupt */
    if (TIMIF & 0x8)
    {       
      TIMIF &= ~0x08;
      /* if LED turn on */
      if (sLEDstate & LED_STATE_ON)
      {  
        sFlashCount1++;
        
        /* flashing mode 1: Slow flashing - 1.5 sec on and 1.5 sec off */
        /* ----------------------------------------------------------- */
        if ( (sLEDstate & LED_STATE_FLASH_MODE_MASK) == LED_STATE_FLASH_MODE_1 )
        {
          /* 200 count ~= 2.5ms x 200 = 0.5s */
          /* 600 count = 1.5s */
          /* > 1.5s, turn off LED */
          if (sFlashCount1 == FLASHCOUNT_1P5_SEC)
            BSP_TURN_OFF_LED2();
          /* > 3s, turn on LED and reset counter */
          else if (sFlashCount1 >= FLASHCOUNT_3_SEC)
          {
            sFlashCount1=0;
            BSP_TURN_ON_LED2();
          }
        }
  
        /* flashing mode 2: Fast flashing - 0.5 sec on and 0.5 sec off */
        /* ----------------------------------------------------------- */
        else if ( (sLEDstate & LED_STATE_FLASH_MODE_MASK) == LED_STATE_FLASH_MODE_2 )
  
        {
          /* > 0.5s, turn off LED */
          if (sFlashCount1 == FLASHCOUNT_0P5_SEC)
            BSP_TURN_OFF_LED2();
          /* > 1s, turn on LED and reset counter */
          else if (sFlashCount1 >= FLASHCOUNT_1_SEC)
          {
            sFlashCount1=0;
            BSP_TURN_ON_LED2();
          }
        }
        
        /* flashing mode 3: Slow flashing for 6 sec then Fast flashing for 4 sec */
        /* --------------------------------------------------------------------- */        
        else if ( (sLEDstate & LED_STATE_FLASH_MODE_MASK) == LED_STATE_FLASH_MODE_3 )
        {
          /* connt2 for switch between Slow between Fast flashing */
          sFlashCount2++;
          /* 0s to 6s, Slow flashing */
          if (sFlashCount2 == 1)
            sFlashCount=FLASHCOUNT_1P5_SEC;
          /* 6s to 10s, Fast flashing */
          if (sFlashCount2 == FLASHCOUNT_6_SEC)
            sFlashCount=FLASHCOUNT_0P5_SEC;
          /* >10s, reset count2 */
          else if (sFlashCount2 >= FLASHCOUNT_10_SEC)
          {
            sFlashCount2=0;
          }
          
          /* Slow or Fast flashing depend on the value set in sFlashCount */
          if (sFlashCount1 == sFlashCount)
            BSP_TURN_OFF_LED2();
          else if ( sFlashCount1 >= (sFlashCount+sFlashCount) )
          {
            sFlashCount1=0;
            BSP_TURN_ON_LED2();
          }
        }
        
        /* flashing mode 4: Fast flashing for 2 sec then pause for 2 sec */
        /* ------------------------------------------------------------- */                
        else if ( (sLEDstate & LED_STATE_FLASH_MODE_MASK) == LED_STATE_FLASH_MODE_4 )
        {          
          sFlashCount2++;
          /* >0.5s, turn off LED */
          if (sFlashCount1 == FLASHCOUNT_0P5_SEC)
            BSP_TURN_OFF_LED2();
          /* >1s */
          else if (sFlashCount1 >= FLASHCOUNT_1_SEC)
          {
            sFlashCount1=0;
            /* <2s, turn on LED */
            if (sFlashCount2 < FLASHCOUNT_2_SEC)
              BSP_TURN_ON_LED2();
            /* 2s to 4s, turn OFF LED */ 
            if (sFlashCount2 >= FLASHCOUNT_4_SEC)
            {
              BSP_TURN_ON_LED2();
              sFlashCount2 = 0;
            }
          }
        }
  
        /* flashing mode 5: Fast flashing for 3 sec at 10/10 duty, 8/10 duty, 6/10 duty, 4/10 duty and 2/10 duty */
        /*                  Flashing for total 15 sec                                                            */
        /* ----------------------------------------------------------------------------------------------------- */                
        else if ( (sLEDstate & LED_STATE_FLASH_MODE_MASK) == LED_STATE_FLASH_MODE_5 )
        {
          sFlashCount2++;
          /* >0.5s, turn off LED */
          /* set ~5% duty for off */
          if (sFlashCount1 == FLASHCOUNT_0P5_SEC)
              SET_TIMER1_PWM_WIDTH(PWM_5_100_DUTY)
          /* >1s, turn on LED w/ differnt duty */
          else if (sFlashCount1 == FLASHCOUNT_1_SEC)
          {
            BSP_TURN_ON_LED2();
            sFlashCount1=0;
            /* ON at 0s, 1s and 2s with 10/10 duty */
            if ( (sFlashCount2 == FLASHCOUNT_1_SEC) || (sFlashCount2 == FLASHCOUNT_2_SEC) )
            {
              T1CNTL = 0x00;      
              BSP_Delay(100);
              T1CTL &= ~0x03;      
            }
            /* ON at 3s, 4s and 5s with 8/10 duty */     
            else if ( (sFlashCount2 == FLASHCOUNT_3_SEC) || (sFlashCount2 == FLASHCOUNT_4_SEC) || (sFlashCount2 == FLASHCOUNT_5_SEC) )
              SET_TIMER1_PWM_WIDTH(PWM_8_10_DUTY)
            /* ON at 6s, 7s and 8s with 6/10 duty */
            else if ( (sFlashCount2 == FLASHCOUNT_6_SEC) || (sFlashCount2 == FLASHCOUNT_7_SEC) || (sFlashCount2 == FLASHCOUNT_8_SEC) )
              SET_TIMER1_PWM_WIDTH(PWM_6_10_DUTY)
            /* ON at 9s, 10s and 11s with 4/10 duty */
            else if ( (sFlashCount2 == FLASHCOUNT_9_SEC) || (sFlashCount2 == FLASHCOUNT_10_SEC) || (sFlashCount2 == FLASHCOUNT_11_SEC) )
              SET_TIMER1_PWM_WIDTH(PWM_4_10_DUTY)
            /* ON at 12s, 13s and 14s with 2/10 duty */
            else if ( (sFlashCount2 == FLASHCOUNT_12_SEC) || (sFlashCount2 == FLASHCOUNT_13_SEC) || (sFlashCount2 == FLASHCOUNT_14_SEC) )
              SET_TIMER1_PWM_WIDTH(PWM_2_10_DUTY)
            /* ON at 15s with 10/10 duty */
            if (sFlashCount2 >= FLASHCOUNT_15_SEC)
            {
              sFlashCount2=0;
              T1CNTL = 0x00;      
              BSP_Delay(100);
              T1CTL &= ~0x03;
            }
          }
        }
      }
    }
}



/**************************************************************************************************
*/
