/**************************************************************************************************
Revised:
Revision:

Copyright 2007 Texas Instruments Incorporated.  All rights reserved.

IMPORTANT: Your use of this Software is limited to those specific rights granted under
the terms of a software license agreement between the user who downloaded the software,
his/her employer (which must be your employer) and Texas Instruments Incorporated (the
"License"). You may not use this Software unless you agree to abide by the terms of the
License. The License limits your use, and you acknowledge, that the Software may not be
modified, copied or distributed unless embedded on a Texas Instruments microcontroller
or used solely and exclusively in conjunction with a Texas Instruments radio frequency
transceiver, which is integrated into your product. Other than for the foregoing purpose,
you may not use, reproduce, copy, prepare derivative works of, modify, distribute,
perform, display or sell this Software and/or its documentation for any purpose.

YOU FURTHER ACKNOWLEDGE AND AGREE THAT THE SOFTWARE AND DOCUMENTATION ARE PROVIDED AS IS
WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION, ANY
WARRANTY OF MERCHANTABILITY, TITLE, NON-INFRINGEMENT AND FITNESS FOR A PARTICULAR PURPOSE.
IN NO EVENT SHALL TEXAS INSTRUMENTS OR ITS LICENSORS BE LIABLE OR OBLIGATED UNDER CONTRACT,
NEGLIGENCE, STRICT LIABILITY, CONTRIBUTION, BREACH OF WARRANTY, OR OTHER LEGAL EQUITABLE
THEORY ANY DIRECT OR INDIRECT DAMAGES OR EXPENSES INCLUDING BUT NOT LIMITED TO ANY
INCIDENTAL, SPECIAL, INDIRECT, PUNITIVE OR CONSEQUENTIAL DAMAGES, LOST PROFITS OR LOST
DATA, COST OF PROCUREMENT OF SUBSTITUTE GOODS, TECHNOLOGY, SERVICES, OR ANY CLAIMS BY
THIRD PARTIES (INCLUDING BUT NOT LIMITED TO ANY DEFENSE THEREOF), OR OTHER SIMILAR COSTS.

Should you have any questions regarding your right to use this Software,
contact Texas Instruments Incorporated at www.TI.com.
**************************************************************************************************/

/* =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
*   BSP (Extended Board Support Package)
* =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
*/

/* ------------------------------------------------------------------------------------------------
*                                            Includes
* ------------------------------------------------------------------------------------------------
*/
#include "bsp.h"
#include "mrfi.h"
#include "nwk_types.h"
#include "nwk_api.h"
#include "bsp_leds.h"
#include "bsp_buttons.h"
#include "bsp_extended.h"

/* ------------------------------------------------------------------------------------------------
 *                                             Macros
 * ------------------------------------------------------------------------------------------------
 */


/* ------------------------------------------------------------------------------------------------
*                                            Local Variables
* ------------------------------------------------------------------------------------------------
*/


/* ------------------------------------------------------------------------------------------------
*                                            Local Functions
* ------------------------------------------------------------------------------------------------
*/
int16_t bsp_AdcSampleSingle(uint8_t reference, uint8_t resolution, uint8_t input);


/**************************************************************************************************
* @fn          initJoystick
*
* @brief       init Joystick port
*
* @param       none
*
* @return      none
**************************************************************************************************
*/
void BSP_InitJoystick(void)
{
  BSP_CONFIG_JOYSTICK();
}


/**************************************************************************************************
* @fn          int16_t bsp_AdcSampleSingle(uint8_t reference, uint8_t resolution, uint8_t input)
*
* @brief       This function makes the adc sample the given channel at the given resolution with the given
*              reference.
*
* @param       uint8_t reference
*                   The reference to compare the channel to be sampled.
*              uint8_t resolution
*                   The resolution to use during the sample (8, 10, 12 or 14 bit)
*              uint8_t input
*                   The channel to be sampled.
*
* @return     int16_t  The conversion result
**************************************************************************************************
*/
int16_t bsp_AdcSampleSingle(uint8_t reference, uint8_t resolution, uint8_t input)
{
    uint8_t volatile temp;
    int16_t value;

    //reading out any old conversion value
    temp = ADCH;
    temp = ADCL;

    ADC_ENABLE_CHANNEL(input);
    ADC_STOP();

    ADC_SINGLE_CONVERSION(reference | resolution | input);

    while (!ADC_SAMPLE_READY());

    ADC_DISABLE_CHANNEL(input);

    value = (((int16_t)ADCH) << 8);
    value |= ADCL;

    ADC_STOP();

    resolution >>= 3;
    return value >> (8 - resolution);
}


/**************************************************************************************************
* @fn          BSP_getJoystickDirection
*
* @brief       This function utilizes the 8-bit ADC to give an indication of the current position of the
*              joystick. Current support is for 90 degrees positioning only.
*
* @param       none
*
* @return     JOYSTICK_DIRECTION:
*               DOWN: Joystick direction is down (270 degrees)
*               LEFT: Joystick direction is left (180 degrees)
*               RIGHT: Joystick direction is right (0 degrees)
*               UP: Joystick direction is up (90 degrees)
*               CENTRED: Joystick direction is centred (passive position)
**************************************************************************************************
*/
joystick_direction_t BSP_getJoystickDirection(void)
{
    int8_t adcValue, i;
    joystick_direction_t direction[2];

    for(i = 0; i < 2; i++) 
    {
        adcValue = bsp_AdcSampleSingle(ADC_REF_AVDD, ADC_8_BIT, ADC_INPUT_JOYSTICK);
        if (adcValue < 0x2E)
            direction[i] = DOWN;
        else if (adcValue < 0x46)
            direction[i] = LEFT;
        else if (adcValue < 0x5F)
            direction[i] = RIGHT;
        else if (adcValue < 0x6F)
            direction[i] = UP;
        else
            direction[i] = CENTRED;
    }
    if(direction[0] == direction[1])
        return direction[0];
    else
       return CENTRED;
}



/**************************************************************************************************
*/
